@@ -1,8 +1,11 @@
 '''
 # Azure DevOps Git Repository Archiver
 
+![Maven Central](https://img.shields.io/maven-central/v/io.github.stefanfreitag/azureS3RepositoryArchiver?color=green&style=flat-square)
 [![npm version](https://badge.fury.io/js/azure-devops-repository-archiver.svg)](https://badge.fury.io/js/azure-devops-repository-archiver)
+[![NuGet version](https://badge.fury.io/nu/Io.Github.StefanFreitag.AzureS3RepositoryArchiver.svg)](https://badge.fury.io/nu/Io.Github.StefanFreitag.AzureS3RepositoryArchiver)
 [![PyPI version](https://badge.fury.io/py/azure-devops-repository-archiver.svg)](https://badge.fury.io/py/azure-devops-repository-archiver)
+
 ![Release](https://github.com/stefanfreitag/azure_s3_repository_archiver/workflows/release/badge.svg)
 
 Allows to backup regularly git repositories hosted in Azure DevOps to an S3 Bucket.
